@@ -9,16 +9,15 @@
 from datetime import datetime
 import re
 try:
-    from urllib.request import *
     from urllib.parse import *
 except ImportError:
-    from urllib2 import *
     from urlparse import *
 
 try:
     from dateutil.parser import parse as parse_date
 except ImportError:
     parse_date = lambda _: identity
+import requests
 
 from miss.identity import *
 from miss.namespace import iNS
